==> volumetric-datagrid-1.0.14.tgz: package/src/store/index.js <==
import Vue from 'vue'
import Vuex from 'vuex'

Vue.use(Vuex);


const defaultGrid = {
  //Фильтр по полям
  filter : {
    data : {},
    show : false,
    filter : function(data){
      console.log('Обьект фильтра : ' , data);
    },
    clear : function(){
      console.log('Функция сброса фильтра');
    }
  },
  pagination : {
    show : 'full',//top//bottom//none
    defaultSize : 10,
    sizes : [10,20,50],
    layout : ['jumper', 'prev', 'pager', 'next', 'sizes', 'total'],
    total : 400,
    page : 1,
    changeSize : function(value){
      console.log(`${value} items per page`);
    },
    changePage : function(value){
      console.log(`current page: ${value}`);
    }
  },
  // Контекстное меню применяемое к каждому ряду таблицы
  context : {
    row : null, // Ряд применения контекста
    menu : [] // Функции контекстного меню
  },
  // Настройки таблицы
  setting : {
    minWidth : 70, // Минимальная ширина при ресайзе колонки
    headerWidth : '', // Высота для настройки липучей шапки , возможно устарело
    columnWidth : {}, // Расчитываемый объект ширины колонок
  },
  header : {}, // Шапка таблицы
  elements : [] // Элементы
};
export default new Vuex.Store({
  state: {
    grid : {}
  },
  mutations: {
    createGrid : function(s,name){
      Vue.set(s.grid, name, defaultGrid);
    },
    normalizeContext : function(s,data){
      s.grid[data.name].context.menu = data.data.context;
    },
    normalizePagination : function(s,data){
      s.grid[data.name].pagination = {
        ...s.grid[data.name].pagination,
        ...data.data.pagination
      }
    },
    normalizeSetting : function(s,data){
      s.grid[data.name].setting = {
        ...s.grid[data.name].setting,
        ...data.data.setting
      }
    },
    normalizeHeader : function(s, data){
      const headerElement = {
        name : 'defaultName',
        width : 70,
        sort : 100,
        show : true,
        child : []
      };
      let headerResult = {};
      for(let key in data.data.header){
        headerResult[key] = {
          ...headerElement,
          ...data.data.header[key]
        }
      }
      s.grid[data.name].header = headerResult;
    },
    normalizeFilter : function(s, data){
      const filter = {
        number : {
          change : [
            {
              value: '=',
              label: 'Точно'
            },
            {
              value: '><',
              label: 'Диапазон'
            },
            {
              value: '>',
              label: 'Больше чем'
            },
            {
              value: '<',
              label: 'Меньше чем'
            }
          ],
          operation : '=',
          min : '',
          max : '',
          show : true
        },
        list : {
          multiple : false,
          value : '',
          option : [],
          changeOption : [],
          show : true
        },
        searchlist : {
          multiple : false,
          value : '',
          option : [],
          changeOption : [],
          show : true,
          query : function(data){
            console.log('Метод для запроса на сервер. Текст запроса : ', data);
          }
        },
        date : {
          change : [
            {
              value: '=',
              label: 'Точно'
            },
            {
              value: '><',
              label: 'Диапазон'
            },
            {
              value: '>',
              label: 'Больше чем'
            },
            {
              value: '<',
              label: 'Меньше чем'
            }
          ],
          operation : '=',
          min : '',
          max : '',
          show : true
        },
      };
      let gridFilter = {
        ...defaultGrid.filter,
        ...data.data.filter
      };
      if('filter' in data.data) {
        for (let key in data.data.filter.data) {
          gridFilter.data[key] = {
            ...filter[data.data.filter.data[key].type],
            ...data.data.filter.data[key],
            key: key
          };
          if ((data.data.filter.data[key].type == 'list' || data.data.filter.data[key].type == 'searchlist') && gridFilter.data[key].multiple)
            gridFilter.data[key].value = [];
        }
      }

      Vue.set(s.grid[data.name], 'filter', gridFilter);
    },
    toggleFilter : function(s,data){
      s.grid[data.name].filter.data[data.key].show = !s.grid[data.name].filter.data[data.key].show;
    },
    virtualHeader : function(s, name){
      let tree = {},
          header = s.grid[name].header,
          root = Object.keys(header),
          list = [],
          listWidth = s.grid[name].setting.minWidth + 'px ',
          scrollWidth = s.grid[name].setting.minWidth,
          treeWidth = {
            root : s.grid[name].setting.minWidth + 'px '
          };

      for(let key in header){
        if(header[key].child.length){
          tree[key] = header[key].child;
          root = root.filter(x => !header[key].child.includes(x));
        }
      }

      tree.root = root;

      for(let key in tree){
        tree[key] = tree[key].sort(function(a,b){
          return header[a].sort - header[b].sort;
        })
      }

      let sortableTree = {};
      for(let key in tree){
        sortableTree[key] = tree[key];
      }

      let exclude = [];
      for(let key in header){
        if(!header[key].show)
          exclude.push(key);
      }

      for(let key in tree){
        tree[key] = tree[key].filter(x => !exclude.includes(x));
      }


      list = (function lists(data){
        let arr = [];
        data.forEach(el => {
          arr.push(el);
          if(el in tree){
            arr = arr.concat(lists(tree[el]));
          }
        });
        return arr;
      })(tree.root);


      list.forEach(key => {
        listWidth += + header[key].width + 'px ';
        scrollWidth += +header[key].width;
      });


      function getNumber(key,tree,header){
        let w = 0;
        if(key in tree) {
          tree[key].forEach(el => {

            w += +header[el].width;

            if (el in tree)
              w += +getNumber(el, tree, header);

          });
        }
        return w;
      }
      function getString(key,tree,header){
        let w = 0,str = '';
        if(key in tree) {
          tree[key].forEach(el => {
            w = 0;
            w += +header[el].width;

            if (el in tree)
              w += +getNumber(el, tree, header);

            str += +w + 'px '

          });
        }
        return str;
      }

      tree.root.forEach(el => {
        treeWidth.root += +header[el].width + getNumber(el,tree,header) + 'px '
      });

      for(let key in tree){
        if(key  !== 'root'){
          treeWidth[key] = '';
          treeWidth[key] += +header[key].width + 'px ' + getString(key,tree,header);
        }
      }

      Vue.set(s.grid[name], 'virtualHeader', {});
      Vue.set(s.grid[name].virtualHeader, 'tree', tree);
      Vue.set(s.grid[name].virtualHeader, 'sortableTree', sortableTree);
      Vue.set(s.grid[name].virtualHeader, 'list', list);
      Vue.set(s.grid[name].virtualHeader, 'listWidth', listWidth);
      Vue.set(s.grid[name].virtualHeader, 'scrollWidth', scrollWidth);
      Vue.set(s.grid[name].virtualHeader, 'treeWidth', treeWidth);
    },
    updateHeader : function(s,data){
      data.update.forEach(el => {
        s.grid[data.grid].header[el.key] = {
          ...s.grid[data.grid].header[el.key],
          ...el.params
        }
      });
    },
    normalizeElement : function(s, data){
      Vue.set(s.grid[data.name], 'elements', data.data.elements);
    },
    showContext : function(s, data){
      Vue.set(s.grid[data.name].context, 'row', data.row);
    },
    hideContext : function(s, name){
      Vue.set(s.grid[name].context, 'row', null);
    },
  },
  actions: {
    createGrid : function({commit},data){
      commit('createGrid',data.name);
      commit('normalizeContext',data);
      commit('normalizePagination',data);
      commit('normalizeSetting',data);
      commit('normalizeHeader',data);
      commit('normalizeFilter',data);
      commit('virtualHeader',data.name);
      commit('normalizeElement',data);
    },
    resize : function({commit},data){
      commit('updateHeader',{
        grid : data.name,
        update : [{
          key : data.key,
          params : {
            width : data.width
          }
        }]
      });
      commit('virtualHeader',data.name);
    },
    sortable : function({commit},data){
      commit('updateHeader',{
        grid : data.name,
        update : data.data
      });
      commit('virtualHeader',data.name);
    }
  },
  getters : {
    keyHeader       : s => name => s.grid[name].keyHeader,
    virtualHeader   : s => name => s.grid[name].virtualHeader,
    context         : s => name => s.grid[name].context,
    pagination      : s => name => s.grid[name].pagination,
    header          : s => name => s.grid[name].header,
    filter          : s => name => s.grid[name].filter,
    setting         : s => name => s.grid[name].setting,
    elements        : s => name => s.grid[name].elements,
  }
});

==> volumetric-datagrid-1.0.20.tgz: package/src/store/index.js <==
import Vue from 'vue'
import Vuex from 'vuex'

Vue.use(Vuex);


const defaultGrid = {
  //Фильтр по полям
  filter : {
    data : {},
    show : false,
    filter : function(data){
      console.log('Обьект фильтра : ' , data);
    },
    clear : function(){
      console.log('Функция сброса фильтра');
    }
  },
  pagination : {
    show : 'full',//top//bottom//none
    defaultSize : 10,
    sizes : [10,20,50],
    layout : ['jumper', 'prev', 'pager', 'next', 'sizes', 'total'],
    total : 400,
    page : 1,
    changeSize : function(value){
      console.log(`${value} items per page`);
    },
    changePage : function(value){
      console.log(`current page: ${value}`);
    }
  },
  // Контекстное меню применяемое к каждому ряду таблицы
  context : {
    row : null, // Ряд применения контекста
    menu : [] // Функции контекстного меню
  },
  // Настройки таблицы
  setting : {
    minWidth : 70, // Минимальная ширина при ресайзе колонки
    headerWidth : '', // Высота для настройки липучей шапки , возможно устарело
    columnWidth : {}, // Расчитываемый объект ширины колонок
  },
  header : {}, // Шапка таблицы
  elements : [] // Элементы
};
export default new Vuex.Store({
  state: {
    grid : {}
  },
  mutations: {
    createGrid : function(s,name){
      Vue.set(s.grid, name, Object.assign({},defaultGrid));
    },
    normalizeContext : function(s,data){
      Vue.set(s.grid[data.name],'context', Object.assign({},defaultGrid.context));
      Vue.set(s.grid[data.name].context, 'menu', Object.assign({},data.data.context));
    },
    normalizePagination : function(s,data){
      s.grid[data.name].pagination = {
        ...s.grid[data.name].pagination,
        ...data.data.pagination
      }
    },
    normalizeSetting : function(s,data){
      s.grid[data.name].setting = {
        ...s.grid[data.name].setting,
        ...data.data.setting
      }
    },
    normalizeHeader : function(s, data){
      const headerElement = {
        name : 'defaultName',
        width : 70,
        sort : 100,
        show : true,
        child : []
      };
      let headerResult = {};

      for(let key in data.data.header){
        headerResult[key] = {
          ...headerElement,
          ...data.data.header[key]
        }
      }

      Vue.set(s.grid[data.name],'header', headerResult);
    },
    normalizeFilter : function(s, data){
      const filter = {
        number : {
          change : [
            {
              value: '=',
              label: 'Точно'
            },
            {
              value: '><',
              label: 'Диапазон'
            },
            {
              value: '>',
              label: 'Больше чем'
            },
            {
              value: '<',
              label: 'Меньше чем'
            }
          ],
          operation : '=',
          min : '',
          max : '',
          show : true
        },
        list : {
          multiple : false,
          value : '',
          option : [],
          changeOption : [],
          show : true
        },
        searchlist : {
          multiple : false,
          value : '',
          option : [],
          changeOption : [],
          show : true,
          query : function(data){
            console.log('Метод для запроса на сервер. Текст запроса : ', data);
          }
        },
        date : {
          change : [
            {
              value: '=',
              label: 'Точно'
            },
            {
              value: '><',
              label: 'Диапазон'
            },
            {
              value: '>',
              label: 'Больше чем'
            },
            {
              value: '<',
              label: 'Меньше чем'
            }
          ],
          operation : '=',
          min : '',
          max : '',
          show : true
        },
      };
      let gridFilter = {
        ...defaultGrid.filter,
        ...data.data.filter
      };
      if('filter' in data.data) {
        for (let key in data.data.filter.data) {
          gridFilter.data[key] = {
            ...filter[data.data.filter.data[key].type],
            ...data.data.filter.data[key],
            key: key
          };
          if ((data.data.filter.data[key].type == 'list' || data.data.filter.data[key].type == 'searchlist') && gridFilter.data[key].multiple)
            gridFilter.data[key].value = [];
        }
      }

      Vue.set(s.grid[data.name], 'filter', gridFilter);
    },
    toggleFilter : function(s,data){
      s.grid[data.name].filter.data[data.key].show = !s.grid[data.name].filter.data[data.key].show;
    },
    virtualHeader : function(s, name){
      let tree = {},
          header = s.grid[name].header,
          root = Object.keys(header),
          list = [],
          listWidth = s.grid[name].setting.minWidth + 'px ',
          scrollWidth = s.grid[name].setting.minWidth,
          treeWidth = {
            root : s.grid[name].setting.minWidth + 'px '
          };

      for(let key in header){
        if(header[key].child.length){
          tree[key] = header[key].child;
          root = root.filter(x => !header[key].child.includes(x));
        }
      }

      tree.root = root;

      for(let key in tree){
        tree[key] = tree[key].sort(function(a,b){
          return header[a].sort - header[b].sort;
        })
      }

      let sortableTree = {};
      for(let key in tree){
        sortableTree[key] = tree[key];
      }

      let exclude = [];
      for(let key in header){
        if(!header[key].show)
          exclude.push(key);
      }

      for(let key in tree){
        tree[key] = tree[key].filter(x => !exclude.includes(x));
      }


      list = (function lists(data){
        let arr = [];
        data.forEach(el => {
          arr.push(el);
          if(el in tree){
            arr = arr.concat(lists(tree[el]));
          }
        });
        return arr;
      })(tree.root);


      list.forEach(key => {
        listWidth += + header[key].width + 'px ';
        scrollWidth += +header[key].width;
      });


      function getNumber(key,tree,header){
        let w = 0;
        if(key in tree) {
          tree[key].forEach(el => {

            w += +header[el].width;

            if (el in tree)
              w += +getNumber(el, tree, header);

          });
        }
        return w;
      }
      function getString(key,tree,header){
        let w = 0,str = '';
        if(key in tree) {
          tree[key].forEach(el => {
            w = 0;
            w += +header[el].width;

            if (el in tree)
              w += +getNumber(el, tree, header);

            str += +w + 'px '

          });
        }
        return str;
      }

      tree.root.forEach(el => {
        treeWidth.root += +header[el].width + getNumber(el,tree,header) + 'px '
      });

      for(let key in tree){
        if(key  !== 'root'){
          treeWidth[key] = '';
          treeWidth[key] += +header[key].width + 'px ' + getString(key,tree,header);
        }
      }

      Vue.set(s.grid[name], 'virtualHeader', {});
      Vue.set(s.grid[name].virtualHeader, 'tree', tree);
      Vue.set(s.grid[name].virtualHeader, 'sortableTree', sortableTree);
      Vue.set(s.grid[name].virtualHeader, 'list', list);
      Vue.set(s.grid[name].virtualHeader, 'listWidth', listWidth);
      Vue.set(s.grid[name].virtualHeader, 'scrollWidth', scrollWidth);
      Vue.set(s.grid[name].virtualHeader, 'treeWidth', treeWidth);
    },
    updateHeader : function(s,data){
      data.update.forEach(el => {
        s.grid[data.grid].header[el.key] = {
          ...s.grid[data.grid].header[el.key],
          ...el.params
        }
      });
    },
    normalizeElement : function(s, data){
      Vue.set(s.grid[data.name], 'elements', data.data.elements);
    },
    showContext : function(s, data){
      Vue.set(s.grid[data.name].context, 'row', data.row);
    },
    hideContext : function(s, name){
      Vue.set(s.grid[name].context, 'row', null);
    },
  },
  actions: {
    createGrid : function({commit},data){
      commit('createGrid',data.name);
      commit('normalizeContext',data);
      commit('normalizePagination',data);
      commit('normalizeSetting',data);
      commit('normalizeHeader',data);
      commit('normalizeFilter',data);
      commit('virtualHeader',data.name);
      commit('normalizeElement',data);
      return true;
    },
    resize : function({commit},data){
      commit('updateHeader',{
        grid : data.name,
        update : [{
          key : data.key,
          params : {
            width : data.width
          }
        }]
      });
      commit('virtualHeader',data.name);
    },
    sortable : function({commit},data){
      commit('updateHeader',{
        grid : data.name,
        update : data.data
      });
      commit('virtualHeader',data.name);
    }
  },
  getters : {
    keyHeader       : s => name => s.grid[name].keyHeader,
    virtualHeader   : s => name => s.grid[name].virtualHeader,
    context         : s => name => s.grid[name].context,
    pagination      : s => name => s.grid[name].pagination,
    header          : s => name => s.grid[name].header,
    filter          : s => name => s.grid[name].filter,
    setting         : s => name => s.grid[name].setting,
    elements        : s => name => s.grid[name].elements,
  }
});
